pub async fn refresh_token(
client_id: u32,
client_secret: &str,
refresh_token: &str,
) -> Result<TokenResponse, ErrorWrapper>Expand description
Swap an expiring access token for a fresh one using a stored refresh token.
pub async fn refresh_token(
client_id: u32,
client_secret: &str,
refresh_token: &str,
) -> Result<TokenResponse, ErrorWrapper>Swap an expiring access token for a fresh one using a stored refresh token.