UploadActivity

Struct UploadActivity 

pub struct UploadActivity { /* private fields */ }
Builder for POST /uploads. Submits an activity file and returns an Upload record. The id on the response can then be polled via GetUpload to check processing progress.

Implementations

Source

impl UploadActivity

pub fn new( url: impl Into<String>, token: impl Into<String>, file: Vec<u8>, data_type: UploadDataType, ) -> Self

pub fn name(self, name: impl Into<String>) -> Self

pub fn description(self, description: impl Into<String>) -> Self

pub fn trainer(self, trainer: bool) -> Self

pub fn commute(self, commute: bool) -> Self

pub fn external_id(self, id: impl Into<String>) -> Self